@@ -1,12 +1,4 @@
-"""
-    sphinx.builders.dummy
-    ~~~~~~~~~~~~~~~~~~~~~
-
-    Do syntax checks, but no writing.
-
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Do syntax checks, but no writing."""
 
 from typing import Any, Dict, Set
 
