@@ -1,13 +1,4 @@
-"""
-    sphinx.errors
-    ~~~~~~~~~~~~~
-
-    Contains SphinxError and a few subclasses (in an extra module to avoid
-    circular import problems).
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Contains SphinxError and a few subclasses."""
 
 from typing import Any
 
