@@ -1,12 +1,4 @@
-"""
-    sphinx.ext.autodoc.mock
-    ~~~~~~~~~~~~~~~~~~~~~~~
-
-    mock for autodoc
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""mock for autodoc"""
 
 import contextlib
 import os
@@ -154,6 +146,11 @@ def mock(modnames: List[str]) -> Generator[None, None, None]:
         finder.invalidate_caches()
 
 
+def ismockmodule(subject: Any) -> bool:
+    """Check if the object is a mocked module."""
+    return isinstance(subject, _MockModule)
+
+
 def ismock(subject: Any) -> bool:
     """Check if the object is mocked."""
     # check the object has '__sphinx_mock__' attribute
@@ -170,7 +167,8 @@ def ismock(subject: Any) -> bool:
     try:
         # check the object is mocked object
         __mro__ = safe_getattr(type(subject), '__mro__', [])
-        if len(__mro__) > 2 and __mro__[1] is _MockObject:
+        if len(__mro__) > 2 and __mro__[-2] is _MockObject:
+            # A mocked object has a MRO that ends with (..., _MockObject, object).
             return True
     except AttributeError:
         pass
