@@ -1,22 +1,16 @@
-"""
-    sphinx.ext.doctest
-    ~~~~~~~~~~~~~~~~~~
+"""Mimic doctest in Sphinx.
 
-    Mimic doctest by automatically executing code snippets and checking
-    their results.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
+The extension automatically execute code snippets and checks their results.
 """
 
 import doctest
 import re
 import sys
 import time
-import warnings
 from io import StringIO
 from os import path
-from typing import Any, Callable, Dict, Iterable, List, Sequence, Set, Tuple
+from typing import (TYPE_CHECKING, Any, Callable, Dict, Iterable, List, Sequence, Set, Tuple,
+                    Type)
 
 from docutils import nodes
 from docutils.nodes import Element, Node, TextElement
@@ -26,17 +20,14 @@ from packaging.version import Version
 
 import sphinx
 from sphinx.builders import Builder
-from sphinx.deprecation import RemovedInSphinx40Warning
 from sphinx.locale import __
 from sphinx.util import logging
 from sphinx.util.console import bold  # type: ignore
 from sphinx.util.docutils import SphinxDirective
 from sphinx.util.osutil import relpath
+from sphinx.util.typing import OptionSpec
 
-if False:
-    # For type annotation
-    from typing import Type  # for python3.5.1
-
+if TYPE_CHECKING:
     from sphinx.application import Sphinx
 
 
@@ -46,17 +37,11 @@ blankline_re = re.compile(r'^\s*<BLANKLINE>', re.MULTILINE)
 doctestopt_re = re.compile(r'#\s*doctest:.+$', re.MULTILINE)
 
 
-def doctest_encode(text: str, encoding: str) -> str:
-    warnings.warn('doctest_encode() is deprecated.',
-                  RemovedInSphinx40Warning, stacklevel=2)
-    return text
-
-
 def is_allowed_version(spec: str, version: str) -> bool:
     """Check `spec` satisfies `version` or not.
 
     This obeys PEP-440 specifiers:
-    https://www.python.org/dev/peps/pep-0440/#version-specifiers
+    https://peps.python.org/pep-0440/#version-specifiers
 
     Some examples:
 
@@ -96,7 +81,7 @@ class TestDirective(SphinxDirective):
                 if not test:
                     test = code
                 code = doctestopt_re.sub('', code)
-        nodetype = nodes.literal_block  # type: Type[TextElement]
+        nodetype: Type[TextElement] = nodes.literal_block
         if self.name in ('testsetup', 'testcleanup') or 'hide' in self.options:
             nodetype = nodes.comment
         if self.arguments:
@@ -160,15 +145,19 @@ class TestDirective(SphinxDirective):
 
 
 class TestsetupDirective(TestDirective):
-    option_spec = {'skipif': directives.unchanged_required}  # type: Dict
+    option_spec: OptionSpec = {
+        'skipif': directives.unchanged_required
+    }
 
 
 class TestcleanupDirective(TestDirective):
-    option_spec = {'skipif': directives.unchanged_required}  # type: Dict
+    option_spec: OptionSpec = {
+        'skipif': directives.unchanged_required
+    }
 
 
 class DoctestDirective(TestDirective):
-    option_spec = {
+    option_spec: OptionSpec = {
         'hide': directives.flag,
         'no-trim-doctest-flags': directives.flag,
         'options': directives.unchanged,
@@ -179,7 +168,7 @@ class DoctestDirective(TestDirective):
 
 
 class TestcodeDirective(TestDirective):
-    option_spec = {
+    option_spec: OptionSpec = {
         'hide': directives.flag,
         'no-trim-doctest-flags': directives.flag,
         'pyversion': directives.unchanged_required,
@@ -189,7 +178,7 @@ class TestcodeDirective(TestDirective):
 
 
 class TestoutputDirective(TestDirective):
-    option_spec = {
+    option_spec: OptionSpec = {
         'hide': directives.flag,
         'no-trim-doctest-flags': directives.flag,
         'options': directives.unchanged,
@@ -207,9 +196,9 @@ parser = doctest.DocTestParser()
 class TestGroup:
     def __init__(self, name: str) -> None:
         self.name = name
-        self.setup = []     # type: List[TestCode]
-        self.tests = []     # type: List[List[TestCode]]
-        self.cleanup = []   # type: List[TestCode]
+        self.setup: List[TestCode] = []
+        self.tests: List[List[TestCode]] = []
+        self.cleanup: List[TestCode] = []
 
     def add_code(self, code: "TestCode", prepend: bool = False) -> None:
         if code.type == 'testsetup':
@@ -397,7 +386,7 @@ Doctest summary
             return False
         else:
             condition = node['skipif']
-            context = {}  # type: Dict[str, Any]
+            context: Dict[str, Any] = {}
             if self.config.doctest_global_setup:
                 exec(self.config.doctest_global_setup, context)
             should_skip = eval(condition, context)
@@ -406,7 +395,7 @@ Doctest summary
             return should_skip
 
     def test_doc(self, docname: str, doctree: Node) -> None:
-        groups = {}  # type: Dict[str, TestGroup]
+        groups: Dict[str, TestGroup] = {}
         add_to_all_groups = []
         self.setup_runner = SphinxDocTestRunner(verbose=False,
                                                 optionflags=self.opt)
@@ -427,7 +416,7 @@ Doctest summary
             def condition(node: Node) -> bool:
                 return isinstance(node, (nodes.literal_block, nodes.comment)) \
                     and 'testnodetype' in node
-        for node in doctree.traverse(condition):  # type: Element
+        for node in doctree.findall(condition):  # type: Element
             if self.skipped(node):
                 continue
 
@@ -487,7 +476,7 @@ Doctest summary
         return compile(code, name, self.type, flags, dont_inherit)
 
     def test_group(self, group: TestGroup) -> None:
-        ns = {}  # type: Dict
+        ns: Dict = {}
 
         def run_setup_cleanup(runner: Any, testcodes: List[TestCode], what: Any) -> bool:
             examples = []
