@@ -1,12 +1,4 @@
-"""
-    sphinx.ext.imgconverter
-    ~~~~~~~~~~~~~~~~~~~~~~~
-
-    Image converter extension for Sphinx
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Image converter extension for Sphinx"""
 
 import subprocess
 import sys
