@@ -1,12 +1,4 @@
-"""
-    sphinx.ext.imgmath
-    ~~~~~~~~~~~~~~~~~~
-
-    Render math in HTML via dvipng or dvisvgm.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Render math in HTML via dvipng or dvisvgm."""
 
 import posixpath
 import re
@@ -65,7 +57,7 @@ def read_svg_depth(filename: str) -> int:
     """Read the depth from comment at last line of SVG file
     """
     with open(filename) as f:
-        for line in f:
+        for line in f:  # noqa: B007
             pass
         # Only last line is checked
         matched = depthsvgcomment_re.match(line)
