@@ -1,14 +1,4 @@
-"""
-    sphinx.ext.napoleon.iterators
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-
-    A collection of helpful iterators.
-
-
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""A collection of helpful iterators."""
 
 import collections
 from typing import Any, Iterable, Optional
@@ -49,8 +39,8 @@ class peek_iter:
     """
     def __init__(self, *args: Any) -> None:
         """__init__(o, sentinel=None)"""
-        self._iterable = iter(*args)        # type: Iterable
-        self._cache = collections.deque()   # type: collections.deque
+        self._iterable: Iterable = iter(*args)
+        self._cache: collections.deque = collections.deque()
         if len(args) == 2:
             self.sentinel = args[1]
         else:
