@@ -1,12 +1,4 @@
-"""
-    sphinx.extension
-    ~~~~~~~~~~~~~~~~
-
-    Utilities for Sphinx extensions.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Utilities for Sphinx extensions."""
 
 from typing import TYPE_CHECKING, Any, Dict
 
