@@ -1,12 +1,4 @@
-"""
-    sphinx.search.da
-    ~~~~~~~~~~~~~~~~
-
-    Danish search language: includes the JS Danish stemmer.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Danish search language: includes the JS Danish stemmer."""
 
 from typing import Dict
 
