@@ -1,12 +1,4 @@
-"""
-    sphinx.util.template
-    ~~~~~~~~~~~~~~~~~~~~
-
-    Templates utility functions for Sphinx.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Templates utility functions for Sphinx."""
 
 import os
 from functools import partial
