@@ -1,3 +1,4 @@
+from datetime import date
 from typing import NewType, TypeVar
 
 #: T1
@@ -15,7 +16,7 @@ T4 = TypeVar("T4", covariant=True)
 T5 = TypeVar("T5", contravariant=True)
 
 #: T6
-T6 = NewType("T6", int)
+T6 = NewType("T6", date)
 
 #: T7
 T7 = TypeVar("T7", bound=int)
@@ -26,4 +27,4 @@ class Class:
     T1 = TypeVar("T1")
 
     #: T6
-    T6 = NewType("T6", int)
+    T6 = NewType("T6", date)
