@@ -1,4 +1,4 @@
-from distutils.core import setup
+from setuptools import setup
 
 from sphinx.setup_command import BuildDoc
 
