@@ -1,12 +1,4 @@
-"""
-    test_api_translator
-    ~~~~~~~~~~~~~~~~~~~
-
-    Test the Sphinx API for translator.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the Sphinx API for translator."""
 
 import sys
 
