@@ -1,12 +1,4 @@
-"""
-    test_application
-    ~~~~~~~~~~~~~~~~
-
-    Test the Sphinx class.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the Sphinx class."""
 
 from unittest.mock import Mock
 
