@@ -1,12 +1,4 @@
-"""
-    test_build_dirhtml
-    ~~~~~~~~~~~~~~~~~~
-
-    Test dirhtml builder.
-
-    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test dirhtml builder."""
 
 import posixpath
 
