@@ -1,12 +1,4 @@
-"""
-    test_build_gettext
-    ~~~~~~~~~~~~~~~~~~
-
-    Test the build process with gettext builder with the test root.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the build process with gettext builder with the test root."""
 
 import gettext
 import os
