@@ -1,12 +1,4 @@
-"""
-    test_build_manpage
-    ~~~~~~~~~~~~~~~~~~
-
-    Test the build process with manpage builder with the test root.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the build process with manpage builder with the test root."""
 
 import pytest
 
