@@ -1,12 +1,4 @@
-"""
-    test_build_text
-    ~~~~~~~~~~~~~~~
-
-    Test the build process with Text builder with the test root.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the build process with Text builder with the test root."""
 
 import pytest
 from docutils.utils import column_width
