@@ -1,13 +1,4 @@
-"""
-    test_config
-    ~~~~~~~~~~~
-
-    Test the sphinx.config.Config class and its handling in the
-    Application class.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the sphinx.config.Config class."""
 
 from unittest import mock
 
