@@ -1,12 +1,4 @@
-"""
-    test_correct_year
-    ~~~~~~~~~~~~~~~~~
-
-    Test copyright year adjustment
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test copyright year adjustment"""
 import pytest
 
 
