@@ -1,12 +1,4 @@
-"""
-    test_directive_other
-    ~~~~~~~~~~~~~~~~~~~~
-
-    Test the other directives.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the other directives."""
 
 import pytest
 from docutils import nodes
