@@ -1,12 +1,4 @@
-"""
-    test_events
-    ~~~~~~~~~~~
-
-    Test the EventManager class.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the EventManager class."""
 
 import pytest
 
