@@ -1,12 +1,4 @@
-"""
-    test_apidoc
-    ~~~~~~~~~~~
-
-    Test the sphinx.apidoc module.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the sphinx.apidoc module."""
 
 from collections import namedtuple
 
@@ -635,6 +627,8 @@ def test_namespace_package_file(tempdir):
     assert content == ("testpkg namespace\n"
                        "=================\n"
                        "\n"
+                       ".. py:module:: testpkg\n"
+                       "\n"
                        "Submodules\n"
                        "----------\n"
                        "\n"
