@@ -1,12 +1,7 @@
-"""
-    test_ext_autodoc
-    ~~~~~~~~~~~~~~~~
+"""Test the autodoc extension.
 
-    Test the autodoc extension.  This tests mainly the Documenters; the auto
-    directives are tested in a test source file translated by test_build.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
+This tests mainly the Documenters; the auto directives are tested in a test
+source file translated by test_build.
 """
 
 import sys
@@ -1870,12 +1865,21 @@ def test_autodoc_GenericAlias(app):
             '   .. py:attribute:: Class.T',
             '      :module: target.genericalias',
             '',
+            '      A list of int',
+            '',
             '      alias of :py:class:`~typing.List`\\ [:py:class:`int`]',
             '',
+            '.. py:attribute:: L',
+            '   :module: target.genericalias',
+            '',
+            '   A list of Class',
+            '',
+            '',
             '.. py:attribute:: T',
             '   :module: target.genericalias',
             '',
-            '   alias of :py:class:`~typing.List`\\ [:py:class:`int`]',
+            '   A list of int',
+            '',
         ]
     else:
         assert list(actual) == [
@@ -1895,6 +1899,15 @@ def test_autodoc_GenericAlias(app):
             '      alias of :py:class:`~typing.List`\\ [:py:class:`int`]',
             '',
             '',
+            '.. py:data:: L',
+            '   :module: target.genericalias',
+            '',
+            '   A list of Class',
+            '',
+            '   alias of :py:class:`~typing.List`\\ '
+            '[:py:class:`target.genericalias.Class`]',
+            '',
+            '',
             '.. py:data:: T',
             '   :module: target.genericalias',
             '',
@@ -1932,7 +1945,7 @@ def test_autodoc_TypeVar(app):
         '',
         '      T6',
         '',
-        '      alias of :py:class:`int`',
+        '      alias of :py:class:`datetime.date`',
         '',
         '',
         '.. py:data:: T1',
@@ -1972,7 +1985,7 @@ def test_autodoc_TypeVar(app):
         '',
         '   T6',
         '',
-        '   alias of :py:class:`int`',
+        '   alias of :py:class:`datetime.date`',
         '',
         '',
         '.. py:data:: T7',
