@@ -1,12 +1,4 @@
-"""
-    test_ext_autodoc_mock
-    ~~~~~~~~~~~~~~~~~~~~~
-
-    Test the autodoc extension.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the autodoc extension."""
 
 import abc
 import sys
@@ -146,6 +138,7 @@ def test_ismock():
 
         assert ismock(mod1) is True
         assert ismock(mod1.Class) is True
+        assert ismock(mod1.submod.Class) is True
         assert ismock(Inherited) is False
 
         assert ismock(mod2) is False
