@@ -1,12 +1,4 @@
-"""
-    test_ext_inheritance_diagram
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    Test sphinx.ext.inheritance_diagram extension.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test sphinx.ext.inheritance_diagram extension."""
 
 import os
 import re
@@ -16,6 +8,7 @@ import pytest
 
 from sphinx.ext.inheritance_diagram import (InheritanceDiagram, InheritanceException,
                                             import_classes)
+from sphinx.util import docutils
 
 
 @pytest.mark.sphinx(buildername="html", testroot="inheritance")
@@ -147,12 +140,20 @@ def test_inheritance_diagram_png_html(app, status, warning):
 
     content = (app.outdir / 'index.html').read_text()
 
-    pattern = ('<div class="figure align-default" id="id1">\n'
-               '<div class="graphviz">'
-               '<img src="_images/inheritance-\\w+.png" alt="Inheritance diagram of test.Foo" '
-               'class="inheritance graphviz" /></div>\n<p class="caption">'
-               '<span class="caption-text">Test Foo!</span><a class="headerlink" href="#id1" '
-               'title="Permalink to this image">\xb6</a></p>')
+    if docutils.__version_info__ < (0, 17):
+        pattern = ('<div class="figure align-default" id="id1">\n'
+                   '<div class="graphviz">'
+                   '<img src="_images/inheritance-\\w+.png" alt="Inheritance diagram of test.Foo" '
+                   'class="inheritance graphviz" /></div>\n<p class="caption">'
+                   '<span class="caption-text">Test Foo!</span><a class="headerlink" href="#id1" '
+                   'title="Permalink to this image">\xb6</a></p>\n</div>\n')
+    else:
+        pattern = ('<figure class="align-default" id="id1">\n'
+                   '<div class="graphviz">'
+                   '<img src="_images/inheritance-\\w+.png" alt="Inheritance diagram of test.Foo" '
+                   'class="inheritance graphviz" /></div>\n<figcaption>\n<p>'
+                   '<span class="caption-text">Test Foo!</span><a class="headerlink" href="#id1" '
+                   'title="Permalink to this image">\xb6</a></p>\n</figcaption>\n</figure>\n')
     assert re.search(pattern, content, re.M)
 
 
@@ -164,14 +165,25 @@ def test_inheritance_diagram_svg_html(app, status, warning):
 
     content = (app.outdir / 'index.html').read_text()
 
-    pattern = ('<div class="figure align-default" id="id1">\n'
-               '<div class="graphviz">'
-               '<object data="_images/inheritance-\\w+.svg" '
-               'type="image/svg\\+xml" class="inheritance graphviz">\n'
-               '<p class=\"warning\">Inheritance diagram of test.Foo</p>'
-               '</object></div>\n<p class="caption"><span class="caption-text">'
-               'Test Foo!</span><a class="headerlink" href="#id1" '
-               'title="Permalink to this image">\xb6</a></p>')
+    if docutils.__version_info__ < (0, 17):
+        pattern = ('<div class="figure align-default" id="id1">\n'
+                   '<div class="graphviz">'
+                   '<object data="_images/inheritance-\\w+.svg" '
+                   'type="image/svg\\+xml" class="inheritance graphviz">\n'
+                   '<p class=\"warning\">Inheritance diagram of test.Foo</p>'
+                   '</object></div>\n<p class="caption"><span class="caption-text">'
+                   'Test Foo!</span><a class="headerlink" href="#id1" '
+                   'title="Permalink to this image">\xb6</a></p>\n</div>\n')
+    else:
+        pattern = ('<figure class="align-default" id="id1">\n'
+                   '<div class="graphviz">'
+                   '<object data="_images/inheritance-\\w+.svg" '
+                   'type="image/svg\\+xml" class="inheritance graphviz">\n'
+                   '<p class=\"warning\">Inheritance diagram of test.Foo</p>'
+                   '</object></div>\n<figcaption>\n<p><span class="caption-text">'
+                   'Test Foo!</span><a class="headerlink" href="#id1" '
+                   'title="Permalink to this image">\xb6</a></p>\n</figcaption>\n</figure>\n')
+
     assert re.search(pattern, content, re.M)
 
 
@@ -204,12 +216,20 @@ def test_inheritance_diagram_latex_alias(app, status, warning):
 
     content = (app.outdir / 'index.html').read_text()
 
-    pattern = ('<div class="figure align-default" id="id1">\n'
-               '<div class="graphviz">'
-               '<img src="_images/inheritance-\\w+.png" alt="Inheritance diagram of test.Foo" '
-               'class="inheritance graphviz" /></div>\n<p class="caption">'
-               '<span class="caption-text">Test Foo!</span><a class="headerlink" href="#id1" '
-               'title="Permalink to this image">\xb6</a></p>')
+    if docutils.__version_info__ < (0, 17):
+        pattern = ('<div class="figure align-default" id="id1">\n'
+                   '<div class="graphviz">'
+                   '<img src="_images/inheritance-\\w+.png" alt="Inheritance diagram of test.Foo" '
+                   'class="inheritance graphviz" /></div>\n<p class="caption">'
+                   '<span class="caption-text">Test Foo!</span><a class="headerlink" href="#id1" '
+                   'title="Permalink to this image">\xb6</a></p>\n</div>\n')
+    else:
+        pattern = ('<figure class="align-default" id="id1">\n'
+                   '<div class="graphviz">'
+                   '<img src="_images/inheritance-\\w+.png" alt="Inheritance diagram of test.Foo" '
+                   'class="inheritance graphviz" /></div>\n<figcaption>\n<p>'
+                   '<span class="caption-text">Test Foo!</span><a class="headerlink" href="#id1" '
+                   'title="Permalink to this image">\xb6</a></p>\n</figcaption>\n</figure>\n')
     assert re.search(pattern, content, re.M)
 
 
