@@ -1,12 +1,4 @@
-"""
-    test_ext_math
-    ~~~~~~~~~~~~~
-
-    Test math extensions.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test math extensions."""
 
 import re
 import subprocess
