@@ -1,12 +1,4 @@
-"""
-    test_pycode_ast
-    ~~~~~~~~~~~~~~~
-
-    Test pycode.ast
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test pycode.ast"""
 
 import sys
 
