@@ -1,16 +1,4 @@
-"""
-    test_pycode_parser
-    ~~~~~~~~~~~~~~~~~~
-
-    Test pycode.parser.
-
-    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
-
-import sys
-
-import pytest
+"""Test pycode.parser."""
 
 from sphinx.pycode.parser import Parser
 from sphinx.util.inspect import signature_from_str
@@ -95,8 +83,7 @@ def test_comment_picker_location():
                                ('Foo', 'attr3'): 'comment for attr3(3)'}
 
 
-@pytest.mark.skipif(sys.version_info < (3, 6), reason='tests for py36+ syntax')
-def test_annotated_assignment_py36():
+def test_annotated_assignment():
     source = ('a: str = "Sphinx"  #: comment\n'
               'b: int = 1\n'
               '"""string on next line"""\n'
@@ -229,7 +216,7 @@ def test_class():
               '\n'
               '    def __init__(self):\n'
               '        self.a = 1 + 1  #: comment3\n'
-              '        self.attr2 = 1 + 1  #: overrided\n'
+              '        self.attr2 = 1 + 1  #: overridden\n'
               '        b = 1 + 1  #: comment5\n'
               '\n'
               '    def some_method(self):\n'
@@ -238,7 +225,7 @@ def test_class():
     parser.parse()
     assert parser.comments == {('Foo', 'attr1'): 'comment1',
                                ('Foo', 'a'): 'comment3',
-                               ('Foo', 'attr2'): 'overrided'}
+                               ('Foo', 'attr2'): 'overridden'}
     assert parser.definitions == {'Foo': ('class', 1, 11),
                                   'Foo.__init__': ('def', 5, 8),
                                   'Foo.some_method': ('def', 10, 11)}
