@@ -1,12 +1,4 @@
-"""
-    test_quickstart
-    ~~~~~~~~~~~~~~~
-
-    Test the sphinx.quickstart module.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the sphinx.quickstart module."""
 
 import time
 from io import StringIO
