@@ -1,12 +1,4 @@
-"""
-    test_roles
-    ~~~~~~~~~~
-
-    Test sphinx.roles
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test sphinx.roles"""
 
 from unittest.mock import Mock
 
