@@ -1,12 +1,4 @@
-"""
-    test_search
-    ~~~~~~~~~~~
-
-    Test the search index builder.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the search index builder."""
 
 from collections import namedtuple
 from io import BytesIO
