@@ -1,12 +1,4 @@
-"""
-    test_setup_command
-    ~~~~~~~~~~~~~~~~~~~
-
-    Test setup_command for distutils.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test setup_command for distutils."""
 
 import os
 import subprocess
