@@ -1,12 +1,4 @@
-"""
-    test_templating
-    ~~~~~~~~~~~~~~~~
-
-    Test templating.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test templating."""
 
 import pytest
 
