@@ -1,12 +1,4 @@
-"""
-    test_theming
-    ~~~~~~~~~~~~
-
-    Test the Theme class.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test the Theme class."""
 
 import os
 
@@ -30,10 +22,10 @@ def test_theme_api(app, status, warning):
         themes.append('alabaster')
 
     # test Theme class API
-    assert set(app.html_themes.keys()) == set(themes)
-    assert app.html_themes['test-theme'] == app.srcdir / 'test_theme' / 'test-theme'
-    assert app.html_themes['ziptheme'] == app.srcdir / 'ziptheme.zip'
-    assert app.html_themes['staticfiles'] == app.srcdir / 'test_theme' / 'staticfiles'
+    assert set(app.registry.html_themes.keys()) == set(themes)
+    assert app.registry.html_themes['test-theme'] == app.srcdir / 'test_theme' / 'test-theme'
+    assert app.registry.html_themes['ziptheme'] == app.srcdir / 'ziptheme.zip'
+    assert app.registry.html_themes['staticfiles'] == app.srcdir / 'test_theme' / 'staticfiles'
 
     # test Theme instance API
     theme = app.builder.theme
@@ -81,7 +73,7 @@ def test_js_source(app, status, warning):
     jquery_src = (app.outdir / '_static' / 'jquery-{v}.js'.format(v=v)).read_text()
     assert 'jQuery JavaScript Library v{v}'.format(v=v) in jquery_src, msg
 
-    v = '1.12.0'
+    v = '1.13.1'
     msg = 'underscore.js version does not match to {v}'.format(v=v)
     underscore_min = (app.outdir / '_static' / 'underscore.js').read_text()
     assert 'Underscore.js {v}'.format(v=v) in underscore_min, msg
@@ -127,7 +119,7 @@ def test_dark_style(app, status, warning):
     assert (app.outdir / '_static' / 'pygments_dark.css').exists()
 
     result = (app.outdir / 'index.html').read_text()
-    assert '<link rel="stylesheet" href="_static/pygments.css" type="text/css" />' in result
+    assert '<link rel="stylesheet" type="text/css" href="_static/pygments.css" />' in result
     assert ('<link id="pygments_dark_css" media="(prefers-color-scheme: dark)" '
             'rel="stylesheet" type="text/css" '
             'href="_static/pygments_dark.css" />') in result
