@@ -1,12 +1,4 @@
-"""
-    test_util_fileutil
-    ~~~~~~~~~~~~~~~~~~
-
-    Tests sphinx.util.fileutil functions.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Tests sphinx.util.fileutil functions."""
 
 from unittest import mock
 
