@@ -1,12 +1,4 @@
-"""
-    test_util_i18n
-    ~~~~~~~~~~~~~~
-
-    Test i18n util.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test i18n util."""
 
 import datetime
 import os
@@ -87,6 +79,12 @@ def test_format_date():
     assert i18n.format_date(format, date=datet) == 'Feb 7, 2016, 5:11:17 AM'
     assert i18n.format_date(format, date=date) == 'Feb 7, 2016'
 
+    # timezone
+    format = '%Z'
+    assert i18n.format_date(format, date=datet) == 'UTC'
+    format = '%z'
+    assert i18n.format_date(format, date=datet) == '+0000'
+
 
 @pytest.mark.xfail(os.name != 'posix', reason="Path separators don't match on windows")
 def test_get_filename_for_language(app):
