@@ -1,12 +1,4 @@
-"""
-    test_util_images
-    ~~~~~~~~~~~~~~~~
-
-    Test images util.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test images util."""
 
 import pytest
 
