@@ -1,12 +1,4 @@
-"""
-    test_util_inventory
-    ~~~~~~~~~~~~~~~~~~~
-
-    Test inventory util functions.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test inventory util functions."""
 
 import posixpath
 import zlib
