@@ -1,17 +1,7 @@
-"""
-    test_util_logging
-    ~~~~~~~~~~~~~~~~~
-
-    Test logging util.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Test logging util."""
 
 import codecs
 import os
-import platform
-import sys
 
 import pytest
 from docutils import nodes
@@ -43,9 +33,9 @@ def test_info_and_warning(app, status, warning):
 
     assert 'message1' not in warning.getvalue()
     assert 'message2' not in warning.getvalue()
-    assert 'message3' in warning.getvalue()
-    assert 'message4' in warning.getvalue()
-    assert 'message5' in warning.getvalue()
+    assert 'WARNING: message3' in warning.getvalue()
+    assert 'CRITICAL: message4' in warning.getvalue()
+    assert 'ERROR: message5' in warning.getvalue()
 
 
 def test_Exception(app, status, warning):
@@ -307,8 +297,8 @@ def test_colored_logs(app, status, warning):
     assert 'message2\n' in status.getvalue()  # not colored
     assert 'message3\n' in status.getvalue()  # not colored
     assert colorize('red', 'WARNING: message4') in warning.getvalue()
-    assert 'WARNING: message5\n' in warning.getvalue()  # not colored
-    assert colorize('darkred', 'WARNING: message6') in warning.getvalue()
+    assert 'CRITICAL: message5\n' in warning.getvalue()  # not colored
+    assert colorize('darkred', 'ERROR: message6') in warning.getvalue()
 
     # color specification
     logger.debug('message7', color='white')
@@ -318,8 +308,6 @@ def test_colored_logs(app, status, warning):
 
 
 @pytest.mark.xfail(os.name != 'posix', reason="Not working on windows")
-@pytest.mark.xfail(platform.system() == 'Darwin' and sys.version_info > (3, 8),
-                   reason="Not working on macOS and py38")
 def test_logging_in_ParallelTasks(app, status, warning):
     logging.setup(app, status, warning)
     logger = logging.getLogger(__name__)
