@@ -1,12 +1,4 @@
-"""
-    test_util_rst
-    ~~~~~~~~~~~~~~~
-
-    Tests sphinx.util.rst functions.
-
-    :copyright: Copyright 2007-2021 by the Sphinx team, see AUTHORS.
-    :license: BSD, see LICENSE for details.
-"""
+"""Tests sphinx.util.rst functions."""
 
 from docutils.statemachine import StringList
 from jinja2 import Environment
